@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Based Mandatory Access Control.
  *
- * Copyright (C) 2005-2006  NTT DATA CORPORATION
+ * Copyright (C) 2005-2007  NTT DATA CORPORATION
  *
- * Version: 1.3   2006/11/11
+ * Version: 1.5.2   2007/12/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -17,8 +17,8 @@
  *  TOMOYO stands for "Task Oriented Management Obviates Your Onus".
  *  TOMOYO is intended to provide the Domain-Based MAC utilizing task_struct.
  *
- *  The biggest feature of TOMOYO is that TOMOYO has "accept mode".
- *  The accept mode can automatically generate policy definition,
+ *  The biggest feature of TOMOYO is that TOMOYO has "learning mode".
+ *  The learning mode can automatically generate policy definition,
  *  and dramatically reduces the policy definition labors.
  *
  *  TOMOYO is applicable to figuring out the system's behavior, for
@@ -34,78 +34,62 @@
 
 /***** TOMOYO Linux start. *****/
 
-#ifdef CONFIG_TOMOYO
-/* Find the next domain to transit to. */
-int FindNextDomain(const char *original_name, struct file *filp, struct domain_info **next_domain, char __user * __user *argv);
-#endif
+struct path_info;
+struct dentry;
+struct vfsmount;
+struct inode;
+struct linux_binprm;
+struct pt_regs;
+
+#if defined(CONFIG_TOMOYO)
 
-#ifdef CONFIG_TOMOYO_MAC_FOR_FILE
 /* Check whether the given filename is allowed to read/write/execute. */
-int CheckFilePerm(const char *filename, const u16 perm, const char *operation);
-int CheckExecPerm(const char *filename, struct file *filp);
+int CheckFilePerm(const char *filename, const u8 perm, const char *operation);
+int CheckExecPerm(const struct path_info *filename, struct file *filp);
 /* Check whether the given dentry is allowed to read/write/execute. */
 int CheckOpenPermission(struct dentry *dentry, struct vfsmount *mnt, const int flag);
 /* Check whether the given dentry is allowed to write. */
 int CheckSingleWritePermission(const unsigned int operation, struct dentry *dentry, struct vfsmount *mnt);
 int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2);
 int CheckReWritePermission(struct file *filp);
-#else
-static inline int CheckFilePerm(const char *filename, const u16 perm, const char *operation) { return 0; }
-static inline int CheckExecPerm(const char *filename, struct file *filp) { return 0; }
-static inline int CheckOpenPermission(struct dentry *dentry, struct vfsmount *mnt, const int flag) { return 0; }
-static inline int CheckSingleWritePermission(const unsigned int operation, struct dentry *dentry, struct vfsmount *mnt) { return 0; }
-static inline int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2) { return 0; }
-static inline int CheckReWritePermission(struct file *filp) { return 0; }
-#endif
 
-#ifdef CONFIG_TOMOYO_MAC_FOR_ARGV0
 /* Check whether the basename of program and argv0 is allowed to differ. */
-int CheckArgv0Perm(const char *filename, const char *argv0);
-#else
-static inline int CheckArgv0Perm(const char *filename, const char *argv0) { return 0; }
-#endif
-
-/* Check whether the given port number is allowed to bind or connect. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_NETWORKPORT
-int CheckBindEntry(const int is_stream, const u16 port);
-int CheckConnectEntry(const int is_stream, const u16 port);
-#else
-static inline int CheckBindEntry(const int is_stream, const u16 port) { return 0; }
-static inline int CheckConnectEntry(const int is_stream, const u16 port) { return 0; }
-#endif
+int CheckArgv0Perm(const struct path_info *filename, const char *argv0);
 
 /* Check whether the given IP address and port number are allowed to use. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_NETWORK
 int CheckNetworkListenACL(const int is_ipv6, const u8 *address, const u16 port);
 int CheckNetworkConnectACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
 int CheckNetworkBindACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
 int CheckNetworkAcceptACL(const int is_ipv6, const u8 *address, const u16 port);
 int CheckNetworkSendMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
 int CheckNetworkRecvMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port);
+
+/* Check whether the given signal is allowed to use. */
+int CheckSignalACL(const int sig, const int pid);
+
+/* Check whether the given capability is allowed to use. */
+int CheckCapabilityACL(const unsigned int capability);
+
 #else
+
+static inline int CheckFilePerm(const char *filename, const u8 perm, const char *operation) { return 0; }
+static inline int CheckExecPerm(const struct path_info *filename, struct file *filp)  { return 0; }
+static inline int CheckOpenPermission(struct dentry *dentry, struct vfsmount *mnt, const int flag) { return 0; }
+static inline int CheckSingleWritePermission(const unsigned int operation, struct dentry *dentry, struct vfsmount *mnt) { return 0; }
+static inline int CheckDoubleWritePermission(const unsigned int operation, struct dentry *dentry1, struct vfsmount *mnt1, struct dentry *dentry2, struct vfsmount *mnt2) { return 0; }
+static inline int CheckReWritePermission(struct file *filp) { return 0; }
+static inline int CheckArgv0Perm(const struct path_info *filename, const char *argv0) { return 0; }
 static inline int CheckNetworkListenACL(const int is_ipv6, const u8 *address, const u16 port) { return 0; }
 static inline int CheckNetworkConnectACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
 static inline int CheckNetworkBindACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
 static inline int CheckNetworkAcceptACL(const int is_ipv6, const u8 *address, const u16 port) { return 0; }
 static inline int CheckNetworkSendMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
 static inline int CheckNetworkRecvMsgACL(const int is_ipv6, const int sock_type, const u8 *address, const u16 port) { return 0; }
-#endif
-
-/* Check whether the given signal is allowed to use. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_SIGNAL
-int CheckSignalACL(const int sig, const int pid);
-#else
 static inline int CheckSignalACL(const int sig, const int pid) { return 0; }
-#endif
-
-/* Check whether the given capability is allowed to use. */
-#ifdef CONFIG_TOMOYO_MAC_FOR_CAPABILITY
-int CheckCapabilityACL(const unsigned int capability);
-#else
 static inline int CheckCapabilityACL(const unsigned int capability) { return 0; }
+
 #endif
 
-struct inode;
 #include <linux/version.h>
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
 int pre_vfs_mknod(struct inode *dir, struct dentry *dentry);
@@ -113,12 +97,11 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry);
 int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 #endif
 
+int search_binary_handler_with_transition(struct linux_binprm *bprm, struct pt_regs *regs);
+#define TOMOYO_CHECK_READ_FOR_OPEN_EXEC 1
+
 /*************************  Index numbers for Access Controls.  *************************/
 
-#define MAKE_ACL_TYPE(x)     ((x) << 16)
-#define GET_ACL_TYPE(x)      ((x) >> 16)
-#define MAKE_ACL_HASH(x)     ((u16) (x))
-#define GET_ACL_HASH(x)      ((u16) (x))
 #define TYPE_CREATE_ACL       0
 #define TYPE_UNLINK_ACL       1
 #define TYPE_MKDIR_ACL        2
@@ -136,11 +119,8 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 #define TYPE_FILE_ACL         100
 #define TYPE_ARGV0_ACL        101
 #define TYPE_CAPABILITY_ACL   102
-#define TYPE_IPv4_NETWORK_ACL 103
-#define TYPE_IPv6_NETWORK_ACL 104
-#define TYPE_SIGNAL_ACL       105
-#define TYPE_CONNECT_ACL      106
-#define TYPE_BIND_ACL         107
+#define TYPE_IP_NETWORK_ACL   103
+#define TYPE_SIGNAL_ACL       104
 
 /*************************  Index numbers for Capability Controls.  *************************/
 
@@ -173,7 +153,8 @@ int pre_vfs_mknod(struct inode *dir, struct dentry *dentry, int mode);
 #define TOMOYO_SYS_CHOWN                        26  /* sys_chown(), sys_fchown(), sys_lchown()                     */
 #define TOMOYO_SYS_IOCTL                        27  /* sys_ioctl(), compat_sys_ioctl()                             */
 #define TOMOYO_SYS_KEXEC_LOAD                   28  /* sys_kexec_load()                                            */
-#define TOMOYO_MAX_CAPABILITY_INDEX             29
+#define TOMOYO_SYS_PIVOT_ROOT                   29  /* sys_pivot_root()                                            */
+#define TOMOYO_MAX_CAPABILITY_INDEX             30
 
 /*************************  Index numbers for Network Controls.  *************************/
 
