@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2007  NTT DATA CORPORATION
  *
- * Version: 1.5.0   2007/09/20
+ * Version: 1.5.2   2007/12/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -36,7 +36,7 @@ static int AuditArgv0Log(const struct path_info *filename, const char *argv0, co
 
 /*************************  ARGV0 MISMATCH HANDLER  *************************/
 
-static int AddArgv0Entry(const char *filename, const char *argv0, struct domain_info *domain, const u8 is_add, const struct condition_list *condition)
+static int AddArgv0Entry(const char *filename, const char *argv0, struct domain_info *domain, const struct condition_list *condition, const u8 is_delete)
 {
 	struct acl_info *ptr;
 	const struct path_info *saved_filename, *saved_argv0;
@@ -44,7 +44,7 @@ static int AddArgv0Entry(const char *filename, const char *argv0, struct domain_
 	if (!IsCorrectPath(filename, 1, 0, -1, __FUNCTION__) || !IsCorrectPath(argv0, -1, 0, -1, __FUNCTION__) || strchr(argv0, '/')) return -EINVAL;
 	if ((saved_filename = SaveName(filename)) == NULL || (saved_argv0 = SaveName(argv0)) == NULL) return -ENOMEM;
 	down(&domain_acl_lock);
-	if (is_add) {
+	if (!is_delete) {
 		if ((ptr = domain->first_acl_ptr) == NULL) goto first_entry;
 		while (1) {
 			struct argv0_acl_record *new_ptr;
@@ -61,7 +61,6 @@ static int AddArgv0Entry(const char *filename, const char *argv0, struct domain_
 				continue;
 			}
 		first_entry: ;
-			if (is_add == 1 && TooManyDomainACL(domain)) break;
 			/* Not found. Append it to the tail. */
 			if ((new_ptr = alloc_element(sizeof(*new_ptr))) == NULL) break;
 			new_ptr->head.type = TYPE_ARGV0_ACL;
@@ -118,7 +117,7 @@ int CheckArgv0Perm(const struct path_info *filename, const char *argv0)
 			printk("TOMOYO-%s: Run %s as %s denied for %s\n", GetMSG(is_enforce), filename->name, argv0, GetLastName(domain));
 		}
 		if (is_enforce) error = CheckSupervisor("%s\n" KEYWORD_ALLOW_ARGV0 "%s %s\n", domain->domainname->name, filename->name, argv0);
-		else if (CheckCCSAccept(CCS_TOMOYO_MAC_FOR_ARGV0)) AddArgv0Entry(filename->name, argv0, domain, 1, NULL);
+		else if (CheckCCSAccept(CCS_TOMOYO_MAC_FOR_ARGV0, domain)) AddArgv0Entry(filename->name, argv0, domain, NULL, 0);
 		if (!is_enforce) error = 0;
 	}
 	return error;
@@ -134,7 +133,7 @@ int AddArgv0Policy(char *data, struct domain_info *domain, const int is_delete)
 	*argv0++ = '\0';
 	cp = FindConditionPart(argv0);
 	if (cp && (condition = FindOrAssignNewCondition(cp)) == NULL) return -EINVAL;
-	return AddArgv0Entry(data, argv0, domain, is_delete ? 0 : -1, condition);
+	return AddArgv0Entry(data, argv0, domain, condition, is_delete);
 }
 
 /***** TOMOYO Linux end. *****/
